@@ -25,7 +25,25 @@ VIDEO_SCHEMA = {
         "frames": "{video_id}_frame_{i}.jpg",  # pattern
     }
 }
+def get_temp_id(url):
+    url = str(url)
+    url_length = len(url)
+    len_neg = 20
+    len_neg = len_neg if url_length >= len_neg else url_length
+    temp_id = re.sub(r'[^\w\d.-]', '_', url)[-len_neg:]
+    return temp_id
+def get_temp_file_name(url):
+    temp_id = get_temp_id(url)
+    temp_filename = f"temp_{temp_id}.mp4"
+    return temp_filename
+def get_display_id(info):
+    display_id = info.get('display_id') or info.get('id')
+    return display_id
 
+def get_safe_title(title):
+    re_str = r'[^\w\d.-]'
+    safe_title = re.sub(re_str, '_', title)
+    return safe_title
 def download_image(url, save_path=None):
     """
     Downloads an image from a URL and saves it to the specified path.
